@@ -1,8 +1,23 @@
+"""
+The podparser is free software: you can redistribute it and/or modify it under
+the terms of the GNU General Public License as published by the Free Software
+Foundation, either version 3 of the License, or (at your option) any later
+version.
+
+The podparser is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with the
+podparser.  If not, see <http://www.gnu.org/licenses/>.
+"""
+
 from datetime        import datetime
 from xml.dom.minidom import parse
 
 import argparse
 import codecs
+import contextlib
 import os
 import sys
 
@@ -36,6 +51,22 @@ def timer(f):
     return deco
 
 
+@contextlib.contextmanager
+def chdir(dirname=None):
+    """
+    Change directory but return to origin after context.
+
+    dirname - the directory to change to
+    """
+
+    curdir = os.getcwd()
+    try:
+        if dirname is not None:
+            os.chdir(dirname)
+        yield
+    finally:
+        os.chdir(curdir)
+
 class Parser:
     """
     Post office directory parser.
@@ -382,17 +413,17 @@ def run_parser():
 
     # parse commandline arguments
     arg_parser = argparse.ArgumentParser(
-        description='Tool for parsing postcode directories')
+        description='Tool for parsing postoffice directories')
 
     parse_group = arg_parser.add_argument_group('Parse Options')
     parse_group.add_argument(
         '-p', '--page',
-        help='single postcode directory page to be parsed')
+        help='single postoffice directory page to be parsed')
 
     parse_group.add_argument(
         '-d', '--directory',
         nargs=1,
-        help='postcode directory to be parsed')
+        help='postoffice directory to be parsed')
     parse_group.add_argument(
         '-s', '--start',
         default=0,
@@ -468,6 +499,7 @@ def run_parser():
         print '*** No directory given ***'
         print arg_parser.print_help()
         sys.exit(1)
+    directory = os.path.abspath(directory)
 
     db_conn = None
     if args.dbpassword:
